@@ -55,7 +55,8 @@ gchar			*as_description_markup_convert (const gchar *markup,
 
 gchar			*as_get_current_locale (void);
 
-gboolean		as_str_empty (const gchar* str);
+AS_INTERNAL_VISIBLE
+gboolean		as_is_empty (const gchar *str);
 GDateTime		*as_iso8601_to_datetime (const gchar *iso_date);
 
 gboolean		as_utils_delete_dir_recursive (const gchar* dirname);
@@ -78,6 +79,7 @@ gboolean		as_utils_is_writable (const gchar *path);
 guint			as_gstring_replace (GString *string,
 					    const gchar *search,
 					    const gchar *replace);
+AS_INTERNAL_VISIBLE
 gchar			*as_str_replace (const gchar *str,
 					 const gchar *old_str,
 					 const gchar *new_str);
