@@ -158,9 +158,11 @@ as_validator_add_issue (AsValidator *validator, xmlNode *node, const gchar *tag,
 		explanation = tag_data->explanation;
 	}
 
-	va_start (args, format);
-	buffer = g_strdup_vprintf (format, args);
-	va_end (args);
+	if (format != NULL) {
+		va_start (args, format);
+		buffer = g_strdup_vprintf (format, args);
+		va_end (args);
+	}
 
 	issue = as_validator_issue_new ();
 	as_validator_issue_set_tag (issue, tag_final);
@@ -430,7 +432,7 @@ as_validator_check_content_empty (AsValidator *validator, xmlNode *node, const g
 	g_autofree gchar *node_content = NULL;
 
 	node_content = as_strstripnl ((gchar*) xmlNodeGetContent (node));
-	if (!as_str_empty (node_content))
+	if (!as_is_empty (node_content))
 		return;
 
 	/* release tags are allowed to be empty */
@@ -450,14 +452,22 @@ as_validator_check_content_empty (AsValidator *validator, xmlNode *node, const g
 static gboolean
 as_validate_has_hyperlink (const gchar *text)
 {
+	gchar *tmp;
 	if (text == NULL)
 		return FALSE;
-	if (g_strstr_len (text, -1, "http://") != NULL)
+
+	tmp = g_strstr_len (text, -1, "https://");
+	if ((tmp != NULL) && (!g_str_has_prefix (tmp + 8, " ")))
 		return TRUE;
-	if (g_strstr_len (text, -1, "https://") != NULL)
+
+	tmp = g_strstr_len (text, -1, "http://");
+	if ((tmp != NULL) && (!g_str_has_prefix (tmp + 7, " ")))
 		return TRUE;
-	if (g_strstr_len (text, -1, "ftp://") != NULL)
+
+	tmp = g_strstr_len (text, -1, "ftp://");
+	if ((tmp != NULL) && (!g_str_has_prefix (tmp + 6, " ")))
 		return TRUE;
+
 	return FALSE;
 }
 
@@ -1151,7 +1161,7 @@ as_validator_check_provides (AsValidator *validator, xmlNode *node, AsComponent
 		node_name = (const gchar*) iter->name;
 		node_content = as_xml_get_node_value (iter);
 		g_strstrip (node_content);
-		if (as_str_empty (node_content)) {
+		if (as_is_empty (node_content)) {
 			as_validator_add_issue (validator, iter,
 						"tag-empty",
 						"%s", node_name);
@@ -1296,19 +1306,19 @@ as_validator_validate_component_node (AsValidator *validator, AsContext *ctx, xm
 		as_validator_add_issue (validator, root, "component-merge-in-metainfo", NULL);
 
 	/* the component must have an id */
-	if (as_str_empty (as_component_get_id (cpt))) {
+	if (as_is_empty (as_component_get_id (cpt))) {
 		/* we don't have an id */
 		as_validator_add_issue (validator, NULL, "component-id-missing", NULL);
 	}
 
 	/* the component must have a name */
-	if (as_str_empty (as_component_get_name (cpt))) {
+	if (as_is_empty (as_component_get_name (cpt))) {
 		/* we don't have a name */
 		as_validator_add_issue (validator, NULL, "component-name-missing", NULL);
 	}
 
 	/* the component must have a summary */
-	if (as_str_empty (as_component_get_summary (cpt))) {
+	if (as_is_empty (as_component_get_summary (cpt))) {
 		/* we don't have a summary */
 		as_validator_add_issue (validator, NULL, "component-summary-missing", NULL);
 	}
@@ -1519,7 +1529,7 @@ as_validator_validate_component_node (AsValidator *validator, AsContext *ctx, xm
 		as_validator_add_issue (validator, NULL, "metadata-license-missing", NULL);
 
 	/* check if we have a description */
-	if (as_str_empty (as_component_get_description (cpt))) {
+	if (as_is_empty (as_component_get_description (cpt))) {
 		AsComponentKind cpt_kind;
 		cpt_kind = as_component_get_kind (cpt);
 
@@ -1951,7 +1961,7 @@ as_validator_analyze_component_metainfo_relation_cb (const gchar *fname, AsCompo
 											G_KEY_FILE_DESKTOP_KEY_CATEGORIES, NULL);
 						cats = g_strsplit (cats_str, ";", -1);
 						for (i = 0; cats[i] != NULL; i++) {
-							if (as_str_empty (cats[i]))
+							if (as_is_empty (cats[i]))
 								continue;
 							if (!as_utils_is_category_name (cats[i])) {
 								as_validator_add_issue (data->validator, NULL,
