@@ -1295,10 +1295,12 @@ static const gchar *xmldata_recommends_requires = "<component>\n"
 						  "  <recommends>\n"
 						  "    <memory>2500</memory>\n"
 						  "    <modalias>usb:v1130p0202d*</modalias>\n"
+						  "    <display_length side=\"longest\" compare=\"le\">4200</display_length>\n"
 						  "  </recommends>\n"
 						  "  <requires>\n"
 						  "    <kernel version=\"4.15\" compare=\"ge\">Linux</kernel>\n"
 						  "    <id version=\"1.2\" compare=\"eq\">org.example.TestDependency</id>\n"
+						  "    <display_length>small</display_length>\n"
 						  "  </requires>\n"
 						  "</component>\n";
 /**
@@ -1320,8 +1322,8 @@ test_xml_read_recommends_requires (void)
 	recommends = as_component_get_recommends (cpt);
 	requires = as_component_get_requires (cpt);
 
-	g_assert_cmpint (recommends->len, ==, 2);
-	g_assert_cmpint (requires->len, ==, 2);
+	g_assert_cmpint (recommends->len, ==, 3);
+	g_assert_cmpint (requires->len, ==, 3);
 
 	/* memory relation */
 	relation = AS_RELATION (g_ptr_array_index (recommends, 0));
@@ -1333,13 +1335,20 @@ test_xml_read_recommends_requires (void)
 	relation = AS_RELATION (g_ptr_array_index (recommends, 1));
 	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_RECOMMENDS);
 	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_MODALIAS);
-	g_assert_cmpstr (as_relation_get_value (relation), ==, "usb:v1130p0202d*");
+	g_assert_cmpstr (as_relation_get_value_str (relation), ==, "usb:v1130p0202d*");
+
+	/* display_length relation (REC) */
+	relation = AS_RELATION (g_ptr_array_index (recommends, 2));
+	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_RECOMMENDS);
+	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_DISPLAY_LENGTH);
+	g_assert_cmpint (as_relation_get_value_px (relation), ==, 4200);
+	g_assert_cmpint (as_relation_get_compare (relation), ==, AS_RELATION_COMPARE_LE);
 
 	/* kernel relation */
 	relation = AS_RELATION (g_ptr_array_index (requires, 0));
 	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_REQUIRES);
 	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_KERNEL);
-	g_assert_cmpstr (as_relation_get_value (relation), ==, "Linux");
+	g_assert_cmpstr (as_relation_get_value_str (relation), ==, "Linux");
 	g_assert_cmpstr (as_relation_get_version (relation), ==, "4.15");
 	g_assert_cmpint (as_relation_get_compare (relation), ==, AS_RELATION_COMPARE_GE);
 
@@ -1347,9 +1356,16 @@ test_xml_read_recommends_requires (void)
 	relation = AS_RELATION (g_ptr_array_index (requires, 1));
 	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_REQUIRES);
 	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_ID);
-	g_assert_cmpstr (as_relation_get_value (relation), ==, "org.example.TestDependency");
+	g_assert_cmpstr (as_relation_get_value_str (relation), ==, "org.example.TestDependency");
 	g_assert_cmpstr (as_relation_get_version (relation), ==, "1.2");
 	g_assert_cmpint (as_relation_get_compare (relation), ==, AS_RELATION_COMPARE_EQ);
+
+	/* display_length relation (REQ) */
+	relation = AS_RELATION (g_ptr_array_index (requires, 2));
+	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_REQUIRES);
+	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_DISPLAY_LENGTH);
+	g_assert_cmpint (as_relation_get_value_display_length_kind (relation), ==, AS_DISPLAY_LENGTH_KIND_SMALL);
+	g_assert_cmpint (as_relation_get_compare (relation), ==, AS_RELATION_COMPARE_GE);
 }
 
 /**
@@ -1366,6 +1382,8 @@ test_xml_write_recommends_requires (void)
 	g_autoptr(AsRelation) moda_relation = NULL;
 	g_autoptr(AsRelation) kernel_relation = NULL;
 	g_autoptr(AsRelation) id_relation = NULL;
+	g_autoptr(AsRelation) dl_relation1 = NULL;
+	g_autoptr(AsRelation) dl_relation2 = NULL;
 
 	cpt = as_component_new ();
 	as_component_set_id (cpt, "org.example.RelationsTest");
@@ -1374,31 +1392,46 @@ test_xml_write_recommends_requires (void)
 	moda_relation = as_relation_new ();
 	kernel_relation = as_relation_new ();
 	id_relation = as_relation_new ();
+	dl_relation1 = as_relation_new ();
+	dl_relation2 = as_relation_new ();
 
 	as_relation_set_kind (mem_relation, AS_RELATION_KIND_RECOMMENDS);
 	as_relation_set_kind (moda_relation, AS_RELATION_KIND_RECOMMENDS);
 	as_relation_set_kind (kernel_relation, AS_RELATION_KIND_REQUIRES);
 	as_relation_set_kind (id_relation, AS_RELATION_KIND_REQUIRES);
+	as_relation_set_kind (dl_relation1, AS_RELATION_KIND_RECOMMENDS);
+	as_relation_set_kind (dl_relation2, AS_RELATION_KIND_REQUIRES);
 
 	as_relation_set_item_kind (mem_relation, AS_RELATION_ITEM_KIND_MEMORY);
-	as_relation_set_value (mem_relation, "2500");
+	as_relation_set_value_int (mem_relation, 2500);
 	as_relation_set_item_kind (moda_relation, AS_RELATION_ITEM_KIND_MODALIAS);
-	as_relation_set_value (moda_relation, "usb:v1130p0202d*");
+	as_relation_set_value_str (moda_relation, "usb:v1130p0202d*");
 
 	as_relation_set_item_kind (kernel_relation, AS_RELATION_ITEM_KIND_KERNEL);
-	as_relation_set_value (kernel_relation, "Linux");
+	as_relation_set_value_str (kernel_relation, "Linux");
 	as_relation_set_version (kernel_relation, "4.15");
 	as_relation_set_compare (kernel_relation, AS_RELATION_COMPARE_GE);
 
 	as_relation_set_item_kind (id_relation, AS_RELATION_ITEM_KIND_ID);
-	as_relation_set_value (id_relation, "org.example.TestDependency");
+	as_relation_set_value_str (id_relation, "org.example.TestDependency");
 	as_relation_set_version (id_relation, "1.2");
 	as_relation_set_compare (id_relation, AS_RELATION_COMPARE_EQ);
 
+	as_relation_set_item_kind (dl_relation1, AS_RELATION_ITEM_KIND_DISPLAY_LENGTH);
+	as_relation_set_value_px (dl_relation1, 4200);
+	as_relation_set_display_side_kind (dl_relation1, AS_DISPLAY_SIDE_KIND_LONGEST);
+	as_relation_set_compare (dl_relation1, AS_RELATION_COMPARE_LE);
+
+	as_relation_set_item_kind (dl_relation2, AS_RELATION_ITEM_KIND_DISPLAY_LENGTH);
+	as_relation_set_value_display_length_kind (dl_relation2, AS_DISPLAY_LENGTH_KIND_SMALL);
+	as_relation_set_compare (dl_relation2, AS_RELATION_COMPARE_GE);
+
 	as_component_add_relation (cpt, mem_relation);
 	as_component_add_relation (cpt, moda_relation);
 	as_component_add_relation (cpt, kernel_relation);
 	as_component_add_relation (cpt, id_relation);
+	as_component_add_relation (cpt, dl_relation1);
+	as_component_add_relation (cpt, dl_relation2);
 
 	res = as_xml_test_serialize (cpt, AS_FORMAT_STYLE_METAINFO);
 	g_assert (as_xml_test_compare_xml (res, xmldata_recommends_requires));
